==> nextcloud-app-news-14.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/sl.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Zahteva je spodletela. Omrežna povezava trenutno ni na voljo!",
    "Request unauthorized. Are you logged in?" : "Zahteva ni ustrezno overjena. Ali ste prijavljeni?",
    "Request forbidden. Are you an admin?" : "Zahteva je zavrnjena. Ali ste prijavljeni kot skrbnik?",
    "Token expired or app not enabled! Reload the page!" : "Ključ je potekel ali pa program ni omogočen! Poskusite osvežiti stran!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Interna napaka strežnika! Preveri data/nextcloud.log datoteko za dodatne informacije!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahteva ni uspela, Nextcloud je trenutno v servisnem načinu!",
    "Can not add feed: Exists already" : "Vira ni mogoče dodati: ta že obstaja",
    "Articles without feed" : "Prispevki brez virov",
    "Can not add folder: Exists already" : "Ni mogoče dodati mape: mapa že obstaja.",
    "News" : "Novice",
    "An RSS/Atom feed reader" : "Bralnik virov RSS/Atom",
    "Use system cron for updates" : "Uporabi sistemski ukaz 'cron' za posodobitve",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Možnost onemogočite, če uporabljate posodabljalnik po meri, kot je na primer posodabljalnik Python, vključen v programski paket",
    "Purge interval" : "Časovni razmik odstranjevanja",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Najkrajši čas, po katerem bodo viri in mape odstranjeni iz podatkovne zbirke. Vrednosti pod 60 sekundami so prezrte.",
    "Maximum read count per feed" : "Največje število prikazanih virov",
    "Maximum redirects" : "Največje število preusmeritev",
    "How many redirects the feed fetcher should follow" : "Koliko preusmeritev naj bralnik virov sledi",
    "Maximum feed page size" : "Največja velikost strani vira",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Največja dovoljena velikost vira v bajtih. Če je vir RSS/ATOM večji od te vrednosti, bo posodobitev prekinjena.",
    "Feed fetcher timeout" : "Čas nalaganja vira",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Čas, ki je namenjen za nalaganje virov RSS ali Atom. Po tem času je nalaganje virov prekinjeno.",
    "Explore Service URL" : "Razišči spletni naslov storitve",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Če je vpisan, bo iz tega servisnega URLja prenesel sporočila za prikaz. Za preklop v vgrajen sistem, pusti to poljeprazno",
    "Saved" : "Shranjeno",
    "Download" : "Prejmi",
    "Close" : "Zapri",
    "filter" : "filter",
    "Language" : "Jezik",
    "Subscribe" : "Naročilo",
    "Got more awesome feeds? Share them with us!" : "Ali ste prejeli več odličnih virov? Pokažite jih tudi nam!",
    "No articles available" : "Ni prispevkov",
    "No unread articles available" : "Ni neprebranih prispevkov",
    "Open website" : "Odpri spletišče",
    "Star article" : "Označi prispevek z zvezdico",
    "Unstar article" : "Odstrani oznako prispevka",
    "Keep article unread" : "Obdrži kot neprebrano",
    "Remove keep article unread" : "Odstrani možnost neprebrano",
    "by" : "od",
    "from" : "od",
    "Play audio" : "Predvajaj zvok",
    "Download video" : "Prejmi video",
    "Download audio" : "Prejmi zvok",
    "Keyboard shortcut" : "Tipkovna bližnica",
    "Description" : "Opis",
    "right" : "desno",
    "Jump to next article" : "Skoči na naslednji prispevek",
    "left" : "levo",
    "Jump to previous article" : "Skoči na predhodni prispevek",
    "Toggle star article" : "Preklopi označevanje z zvezdico",
    "Star article and jump to next one" : "Označi prispevek z zvezdico in skoči na naslednjega",
    "Toggle keep current article unread" : "Preklopi ohranjanje prispevka kot neprebranega",
    "Open article in new tab" : "Odpri prispevek v novem zavihku",
    "Toggle expand article in compact view" : "Preklopi razširitev prispevka v skrčenem pogledu",
    "Refresh" : "Osveži",
    "Load next feed" : "Naloži naslednji vir",
    "Load previous feed" : "Naloži predhodni vir",
    "Load next folder" : "Naloži naslednjo mapo",
    "Load previous folder" : "Naloži predhodno mapo",
    "Scroll to active navigation entry" : "Pomakni se na predmet v žarišču",
    "Focus search field" : "Postavi iskalno polje v žarišče",
    "Mark current article's feed/folder read" : "Označi trenutni predmet kot prebran",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zaznan je način Ajax oziroma webcron! Izbrani viri ne bodo posodobljeni!",
    "How to set up the operating system cron" : "Kako nastaviti opravila cron operacijskega sistema",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Namesti in nastavi hitrejši vzporedni posodabljalnik, ki za posodobitev uporablja  API programa  News",
    "Web address" : "Spletni naslov",
    "Feed exists already!" : "Vir že obstaja!",
    "Folder" : "Mapa",
    "No folder" : "Ni mape",
    "New folder" : "Nova mapa",
    "Folder name" : "Ime mape",
    "Go back" : "Nazaj",
    "Folder exists already!" : "Mapa že obstaja!",
    "Credentials" : "Poverila",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth podatki morajo biti shranjeni nekodirani! Vsakdo z dostopom do baze jih lahko vidi!",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "New Folder" : "Nova mapa",
    "Create" : "Ustvari",
    "Explore" : "Razišči",
    "Update failed more than 50 times" : "Posodobitev je spodletela več kot 50-krat",
    "Deleted feed" : "Izbrisan vir",
    "Undo delete feed" : "Razveljavi brisanje vira",
    "Rename" : "Preimenuj",
    "Menu" : "Meni",
    "Enable full text" : "Omogoči polno besedilo",
    "Delete" : "Izbriši",
    "Dismiss" : "Opusti",
    "Collapse" : "Skrči",
    "Deleted folder" : "Izbrisana mapa",
    "Undo delete folder" : "Razveljavi brisanje mape",
    "Starred" : "Z zvezdico",
    "Unread articles" : "Neprebrani prispevki",
    "All articles" : "Vsi prispevki",
    "Settings" : "Nastavitve",
    "Disable mark read through scrolling" : "Onemogoči označevanje prebranosti med drsenjem",
    "Compact view" : "Stisnjen pogled",
    "Expand articles on key navigation" : "Razširi prispevek s tipkovnim krmarjenjem",
    "Show all articles" : "Pokaži vse prispevke",
    "Reverse ordering (oldest on top)" : "Obrni razvrstitev (najstarejši na vrh)",
    "Subscriptions (OPML)" : "Naročnine (OPML)",
    "Import" : "Uvozi",
    "Export" : "Izvozi",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Napaka med uvažanjem: datoteka OPML ne vsebuje niti virov niti map",
    "Unread/Starred Articles" : "Neprebrani/Označeni prispevki",
    "Error when importing: file does not contain valid JSON" : "Napaka uvoza: datoteka ne vsebuje veljavnih podatkov JSON.",
    "Help" : "Pomoč",
    "Keyboard shortcuts" : "Tipkovne bližnjice",
    "Documentation" : "Dokumentacija",
    "Report a bug" : "Pošlji poročilo o hrošču"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-app-news-14.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/sl.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Zahteva je spodletela. Omrežna povezava trenutno ni na voljo!",
    "Request unauthorized. Are you logged in?" : "Zahteva ni ustrezno overjena. Ali ste prijavljeni?",
    "Request forbidden. Are you an admin?" : "Zahteva je zavrnjena. Ali ste prijavljeni kot skrbnik?",
    "Token expired or app not enabled! Reload the page!" : "Ključ je potekel ali pa program ni omogočen! Poskusite osvežiti stran!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Interna napaka strežnika! Preveri data/nextcloud.log datoteko za dodatne informacije!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Zahteva ni uspela, Nextcloud je trenutno v servisnem načinu!",
    "Can not add feed: Exists already" : "Vira ni mogoče dodati: ta že obstaja",
    "Articles without feed" : "Prispevki brez virov",
    "Can not add folder: Exists already" : "Ni mogoče dodati mape: mapa že obstaja.",
    "News" : "Novice",
    "An RSS/Atom feed reader" : "Bralnik virov RSS/Atom",
    "Use system cron for updates" : "Uporabi sistemski ukaz 'cron' za posodobitve",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Možnost onemogočite, če uporabljate posodabljalnik po meri, kot je na primer posodabljalnik Python, vključen v programski paket",
    "Purge interval" : "Časovni razmik odstranjevanja",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Najkrajši čas, po katerem bodo viri in mape odstranjeni iz podatkovne zbirke. Vrednosti pod 60 sekundami so prezrte.",
    "Maximum read count per feed" : "Največje število prikazanih virov",
    "Maximum redirects" : "Največje število preusmeritev",
    "How many redirects the feed fetcher should follow" : "Koliko preusmeritev naj bralnik virov sledi",
    "Maximum feed page size" : "Največja velikost strani vira",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Največja dovoljena velikost vira v bajtih. Če je vir RSS/ATOM večji od te vrednosti, bo posodobitev prekinjena.",
    "Feed fetcher timeout" : "Čas nalaganja vira",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Čas, ki je namenjen za nalaganje virov RSS ali Atom. Po tem času je nalaganje virov prekinjeno.",
    "Explore Service URL" : "Razišči spletni naslov storitve",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Če je podan, bo prek tega naslova URL storitve potekala poizvedba za vire in njihov i zbor. Za preklop v vgrajeno storitev določevanja, mora biti polje prazno.",
    "Saved" : "Shranjeno",
    "Download" : "Prejmi",
    "Close" : "Zapri",
    "filter" : "filter",
    "Language" : "Jezik",
    "Subscribe" : "Naročilo",
    "Got more awesome feeds? Share them with us!" : "Ali ste prejeli več odličnih virov? Pokažite jih tudi nam!",
    "No articles available" : "Ni prispevkov",
    "No unread articles available" : "Ni neprebranih prispevkov",
    "Open website" : "Odpri spletišče",
    "Star article" : "Označi prispevek z zvezdico",
    "Unstar article" : "Odstrani zvezdico s prispevka",
    "Keep article unread" : "Obdrži kot neprebrano",
    "Remove keep article unread" : "Odstrani možnost neprebrano",
    "by" : "od",
    "from" : "od",
    "Play audio" : "Predvajaj zvok",
    "Download audio" : "Prejmi zvok",
    "Download video" : "Prejmi video",
    "Keyboard shortcut" : "Tipkovna bližnica",
    "Description" : "Opis",
    "right" : "desno",
    "Jump to next article" : "Skoči na naslednji prispevek",
    "left" : "levo",
    "Jump to previous article" : "Skoči na predhodni prispevek",
    "Toggle star article" : "Preklopi označevanje z zvezdico",
    "Star article and jump to next one" : "Označi prispevek z zvezdico in skoči na naslednjega",
    "Toggle keep current article unread" : "Preklopi ohranjanje prispevka kot neprebranega",
    "Open article in new tab" : "Odpri prispevek v novem zavihku",
    "Toggle expand article in compact view" : "Preklopi razširitev prispevka v skrčenem pogledu",
    "Refresh" : "Osveži",
    "Load next feed" : "Naloži naslednji vir",
    "Load previous feed" : "Naloži predhodni vir",
    "Load next folder" : "Naloži naslednjo mapo",
    "Load previous folder" : "Naloži predhodno mapo",
    "Scroll to active navigation entry" : "Pomakni se na predmet v žarišču",
    "Focus search field" : "Postavi iskalno polje v žarišče",
    "Mark current article's feed/folder read" : "Označi trenutni predmet kot prebran",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zaznan je način Ajax oziroma webcron! Izbrani viri ne bodo posodobljeni!",
    "How to set up the operating system cron" : "Kako nastaviti opravila cron operacijskega sistema",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Namesti in nastavi hitrejši vzporedni posodabljalnik, ki za posodobitev uporablja  API programa  News",
    "Web address" : "Spletni naslov",
    "Feed exists already!" : "Vir že obstaja!",
    "Folder" : "Mapa",
    "No folder" : "Ni mape",
    "New folder" : "Nova mapa",
    "Folder name" : "Ime mape",
    "Go back" : "Nazaj",
    "Folder exists already!" : "Mapa že obstaja!",
    "Credentials" : "Poverila",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth podatki morajo biti shranjeni nekodirani! Vsakdo z dostopom do baze jih lahko vidi!",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "New Folder" : "Nova mapa",
    "Create" : "Ustvari",
    "Explore" : "Razišči",
    "Update failed more than 50 times" : "Posodobitev je spodletela več kot 50-krat",
    "Deleted feed" : "Izbrisan vir",
    "Undo delete feed" : "Razveljavi brisanje vira",
    "Rename" : "Preimenuj",
    "Menu" : "Meni",
    "Mark read" : "Označi kot prebrano",
    "Unpin from top" : "Odpni z vrha",
    "Pin to top" : "Pripni na vrh",
    "Newest first" : "najprej najnovejše",
    "Oldest first" : "najprej najstarejše",
    "Default order" : "Privzeta razvrstitev",
    "Enable full text" : "Omogoči polno besedilo",
    "Disable full text" : "Omogoči polno besedilo",
    "Ignore updated" : "Prezri posodobljeno",
    "Delete" : "Izbriši",
    "Dismiss" : "Opusti",
    "Collapse" : "Skrči",
    "Deleted folder" : "Izbrisana mapa",
    "Undo delete folder" : "Razveljavi brisanje mape",
    "Starred" : "Z zvezdico",
    "Unread articles" : "Neprebrani prispevki",
    "All articles" : "Vsi prispevki",
    "Settings" : "Nastavitve",
    "Disable mark read through scrolling" : "Onemogoči označevanje prebranosti med drsenjem",
    "Compact view" : "Stisnjen pogled",
    "Expand articles on key navigation" : "Razširi prispevek s tipkovnim krmarjenjem",
    "Show all articles" : "Pokaži vse prispevke",
    "Reverse ordering (oldest on top)" : "Obrni razvrstitev (najstarejši na vrh)",
    "Subscriptions (OPML)" : "Naročnine (OPML)",
    "Import" : "Uvozi",
    "Export" : "Izvozi",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Napaka med uvažanjem: datoteka OPML ne vsebuje niti virov niti map",
    "Unread/Starred Articles" : "Neprebrani/Označeni prispevki",
    "Error when importing: file does not contain valid JSON" : "Napaka uvoza: datoteka ne vsebuje veljavnih podatkov JSON.",
    "Help" : "Pomoč",
    "Keyboard shortcuts" : "Tipkovne bližnjice",
    "Documentation" : "Dokumentacija",
    "Report a bug" : "Pošlji poročilo o hrošču"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
